==> abb-0.1.tar.gz: abb-0.1/abb/handler.py <==
import datetime
import json
import uuid

from abb.core import env
from contextlib import contextmanager
from pyld import jsonld
from sparqltools.client import TornadoClient, ClientError
# from sparqltools.query import QueryBuilder
from tornado.gen import coroutine
from tornado.web import RequestHandler, HTTPError

JSONLD_CONTENT_TYPE = "application/ld+json"


def get_namespace():
    return env('NAMESPACE')


def get_context_url():
    return "/%s" % env('CONTEXT_FILE')


def get_namespaces():
    namespaces = (
        ("", get_namespace()),
    )
    return namespaces


class Error(HTTPError):
    code = 500
    message = "An unknown error occurred"

    def __init__(self, message=None):
        if message:
            self.message = message
        super().__init__(self.code, self.message)


class ErrorList(Error):
    code = 400
    message = "Request failed with errors"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.details = []

    def __len__(self):
        return len(self.details)

    @contextmanager
    def catch(self, scope):
        try:
            yield
        except Error as error:
            self.details.append({
                "scope": scope,
                "name": error.__class__.__name__,
                "message": error.message
            })

    def propagate(self):
        if self.details:
            raise self


class InvalidPayloadError(Error):
    code = 415
    message = "Invalid or unsupported data has been submitted"


class BaseHandler(RequestHandler):
    def initialize(self):
        port = env('VIRTUOSO_PORT_8890_TCP_PORT')
        addr = env('VIRTUOSO_PORT_8890_TCP_ADDR')
        endpoint = "http://%s:%s/sparql" % (addr, port)
        self._client = TornadoClient(
            endpoint,
            endpoint,
            default_graph=env('DEFAULT_GRAPH_URI'),
            dump_dir=env('DUMP_DIR')
        )

    def get_utc_now(self):
        now = datetime.datetime.now(datetime.timezone.utc)
        return now

    def get_new_uuid(self):
        return uuid.uuid4().hex

    @coroutine
    def query_jsonld(self, query):
        response = yield self._client.send_query(query, "jsonld")
        document = jsonld.compact(response, get_context_url())
        return document

    def receive_jsonld(self, excepted_type=None):
        if self.request.headers["Content-Type"] != JSONLD_CONTENT_TYPE:
            raise InvalidPayloadError("Unsupported Content-Type")

        try:
            payload = self.request.body.decode("utf-8")
            payload = json.loads(payload)
            document = jsonld.compact(payload, get_context_url())
        except Exception:
            raise InvalidPayloadError("Invalid payload structure")

        if excepted_type and (document.get("_type") != excepted_type):
            raise InvalidPayloadError("Invalid payload type")

        return document

    def compute_etag(self):
        return None

    def write_error(self, status_code, **kwargs):
        exc = kwargs.get("exc_info")

        if not exc:
            super().write_error(status_code, **kwargs)
            return

        eclass = exc[0]

        if not issubclass(eclass, Error) and not issubclass(eclass, ClientError):
            super().write_error(status_code, **kwargs)
            return

        response = {
            "_type": "Error",
            "name": eclass.__name__,
            "message": exc[1].message
        }

        # TODO json-ld friendly embedding
        if getattr(exc[1], "details", None):
            response["details"] = exc[1].details

        self.write_jsonld(response)

    def write_jsonld(self, doc=None, status_code=None):
        self.set_header("Content-Type", JSONLD_CONTENT_TYPE)

        if status_code is not None:
            self.set_status(status_code)

        if doc is not None:
            if not doc.get("@context"):
                doc["@context"] = get_context_url()
            self.write(json.dumps(doc))

==> abb-0.3.tar.gz: abb-0.3/abb/handler.py <==
import datetime
import json
import uuid

from abb.core import env
from contextlib import contextmanager
from pyld import jsonld
from sparqltools.client import TornadoClient, ClientError
from tornado.gen import coroutine
from tornado.web import RequestHandler, HTTPError

JSONLD_CONTENT_TYPE = "application/ld+json"


def get_namespace():
    return env('NAMESPACE')


def get_context_url():
    return "/%s" % env('CONTEXT_FILE')


def get_namespaces():
    namespaces = (
        ("", get_namespace()),
    )
    return namespaces


class Error(HTTPError):
    code = 500
    message = "An unknown error occurred"

    def __init__(self, message=None):
        if message:
            self.message = message
        super().__init__(self.code, self.message)


class ErrorList(Error):
    code = 400
    message = "Request failed with errors"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.details = []

    def __len__(self):
        return len(self.details)

    @contextmanager
    def catch(self, scope):
        try:
            yield
        except Error as error:
            self.details.append({
                "scope": scope,
                "name": error.__class__.__name__,
                "message": error.message
            })

    def propagate(self):
        if self.details:
            raise self


class InvalidPayloadError(Error):
    code = 415
    message = "Invalid or unsupported data has been submitted"


class BaseHandler(RequestHandler):
    def initialize(self):
        port = env('VIRTUOSO_PORT_8890_TCP_PORT')
        addr = env('VIRTUOSO_PORT_8890_TCP_ADDR')
        endpoint = "http://%s:%s/sparql" % (addr, port)
        self._client = TornadoClient(
            endpoint,
            endpoint,
            env('DEFAULT_GRAPH_URI'),
            dump_dir=env('DUMP_DIR')
        )

    def get_utc_now(self):
        now = datetime.datetime.now(datetime.timezone.utc)
        return now

    def get_new_uuid(self):
        return uuid.uuid4().hex

    @coroutine
    def query_jsonld(self, query):
        response = yield self._client.send_query(query, "jsonld")
        document = jsonld.compact(response, get_context_url())
        return document

    def receive_jsonld(self, excepted_type=None):
        if self.request.headers["Content-Type"] != JSONLD_CONTENT_TYPE:
            raise InvalidPayloadError("Unsupported Content-Type")

        try:
            payload = self.request.body.decode("utf-8")
            payload = json.loads(payload)
            document = jsonld.compact(payload, get_context_url())
        except Exception:
            raise InvalidPayloadError("Invalid payload structure")

        if excepted_type and (document.get("_type") != excepted_type):
            raise InvalidPayloadError("Invalid payload type")

        return document

    def compute_etag(self):
        return None

    def write_error(self, status_code, **kwargs):
        exc = kwargs.get("exc_info")

        if not exc:
            super().write_error(status_code, **kwargs)
            return

        eclass = exc[0]

        if not issubclass(eclass, Error) and not issubclass(eclass, ClientError):
            super().write_error(status_code, **kwargs)
            return

        response = {
            "_type": "Error",
            "name": eclass.__name__,
            "message": exc[1].message
        }

        # TODO json-ld friendly embedding
        if getattr(exc[1], "details", None):
            response["details"] = exc[1].details

        self.write_jsonld(response)

    def write_jsonld(self, doc=None, status_code=None):
        self.set_header("Content-Type", JSONLD_CONTENT_TYPE)

        if status_code is not None:
            self.set_status(status_code)

        if doc is not None:
            if not doc.get("@context"):
                doc["@context"] = get_context_url()
            self.write(json.dumps(doc))
